Package: AMCP
Type: Package
Title: Data Sets to Accompany Designing Experiments and Analyzing Data:
        A Model Comparison Perspective (Maxwell, Delaney, and Kelley,
        2027, 4th Edition)
Version: 2.0.0
Date: 2026-07-21
Authors@R: c(person(given="Scott E.", family="Maxwell", role = "aut"), person(given="Harold D.", family="Delaney", role = "aut"), person("Ken", "Kelley", role = c("aut", "cre"), email = "kkelley@nd.edu"))
Description: Data sets that accompany the book "Designing experiments and
    analyzing data: A model comparison perspective" (4th ed.) by
    Maxwell, Delaney, and Kelley (2027; ISBN 978-1-041-25384-6; Routledge).
    Contains all of the data sets in the book's chapters and end-of-chapter
    exercises. Beginning with version 2.0, the package is tailored to the 4th
    edition of the book; for the data as distributed with the 3rd edition
    (2018), install the archived version 1.0.2 from CRAN. We recommend the
    'DMAR' package as the companion for carrying out the book's analyses; these
    analyses are illustrated in the book itself using the 'MBESS' package, which
    may be used as well. The book's companion website is available at
    <https://designingexperiments.com/> and its publisher page at
    <https://www.routledge.com/Designing-Experiments-and-Analyzing-Data-A-Model-Comparison-Perspective/Maxwell-Delaney-Kelley/p/book/9781041253846>.
URL: https://designingexperiments.com/, https://kenkelley.org/,
        https://github.com/yelleKneK/AMCP
BugReports: https://github.com/yelleKneK/AMCP/issues
License: GPL (>= 3)
Encoding: UTF-8
Language: en-US
Depends: R (>= 4.0.0)
Suggests: testthat (>= 3.0.0), knitr, rmarkdown
VignetteBuilder: knitr
RoxygenNote: 7.3.2
LazyData: true
Config/testthat/edition: 3
NeedsCompilation: no
Packaged: 2026-07-21 23:31:23 UTC; kkelley
Author: Scott E. Maxwell [aut],
  Harold D. Delaney [aut],
  Ken Kelley [aut, cre]
Maintainer: Ken Kelley <kkelley@nd.edu>
Repository: CRAN
Date/Publication: 2026-07-22 08:30:37 UTC
