% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/documentation.R
\docType{data}
\name{chapter_14_table_7}
\alias{chapter_14_table_7}
\alias{C14T7}
\alias{Chapter_14_Table_7}
\alias{c14t7}
\title{The data used in Chapter 14, Table 7}
\format{
An object of class \code{data.frame} with 20 rows and 3 columns.
}
\source{
\url{https://designingexperiments.com/data/}

Maxwell, S. E., Delaney, H. D., & Kelley, K. (2027). \emph{Designing experiments and
analyzing data: {A} model comparison perspective}. (4th ed.). New York, NY: Routledge.
}
\usage{
data(chapter_14_table_7)
}
\description{
The data used in Chapter 14, Table 7
}
\details{
For the hypothetical data contained in Table 14.7, a perceptual psychologist is interested in age differences ("young" and "old") in reaction time on a perceptual task. In addition, the psychologist is also interested in the effect of angle (zero degrees off center and eight degrees off center). The question of interest is to see if there are is a main effect of age, a main effect of angle, and an interaction between the two. Table 14.7 presents the same data that we analyzed in chapter 12 for 10 young participants and 10 old participants, except that for the moment we are only analyzing data from the 0 degree and 8 degree conditions of the angle factor.

In any two factor design, the effects to be tested are typically the two main effects and the two-way interaction. In our example, then, we test the main effect of age (designated A), the main effect of angle (designated B), and the interaction of age and angle.
}
\note{
Renumbered for the 4th edition: in the 3rd edition (AMCP 1.x) these reaction-time data were Table 14.8 (\code{chapter_14_table_8} / \code{C14T8}). The data are unchanged, but note that \code{chapter_14_table_8} now holds different (transformed-score) data.
}
\section{Variables}{

\describe{
\item{Angle0}{participant reaction time at angle 0}
\item{Angle8}{participant reaction time at angle 8}
\item{Group}{participant age (young or old)}
}
}

\section{Synonym}{

C14T7
}

\examples{
# Load the data
data(chapter_14_table_7)

# Or, alternatively load the data as
data(C14T7)

# View the structure
str(chapter_14_table_7)

}
\references{
Maxwell, S. E., Delaney, H. D., & Kelley, K. (2027). \emph{Designing experiments and analyzing data:
{A} model comparison perspective} (4th ed.). New York, NY: Routledge.
}
\author{
Ken Kelley \email{kkelley@nd.edu}
}
\keyword{datasets}
