% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/documentation.R
\docType{data}
\name{chapter_12_table_29}
\alias{chapter_12_table_29}
\alias{C12T29}
\alias{Chapter_12_Table_29}
\alias{c12t29}
\title{The data used in Chapter 12, Table 29}
\format{
An object of class \code{data.frame} with 18 rows and 5 columns.
}
\source{
\url{https://designingexperiments.com/data/}

Maxwell, S. E., Delaney, H. D., & Kelley, K. (2027). \emph{Designing experiments and
analyzing data: {A} model comparison perspective}. (4th ed.). New York, NY: Routledge.
}
\usage{
data(chapter_12_table_29)
}
\description{
The data used in Chapter 12, Table 29
}
\details{
Suppose that we are interested in comparing the effects of three drugs (A, B, and C) on aggressiveness on monkeys. To control for possible order effects, we use a Latin square design. Specifically, we suppose that six subjects are available (as we discussed in Chapter 11, a subject is actually a pair of monkeys in this design). Following the design principles outlined at the end of Chapter 11, we use a replicated Latin square design with two randomly constituted squares. Subjects are then randomly assigned to rows of the squares. The dependent measure can be thought of as the number of aggressive behaviors engaged in during a fixed time period. Notice that each score is a function of three possible influences: subject, time period, and treatment condition (where here is drug, with three levels, either A, B, or C).

To summarize, the data in Table 12.29 consists of hypothetical aggressiveness scores for 6 monkeys who have been exposed to three types of drugs (A, B, and C). In order to control for potential order effects, a Latin square design is utilized. In particular, two randomly constituted squares are formed with three monkeys randomly assigned to each square and also randomly assigned to the particular row of the square that assigns the order that they are exposed to treatment.
}
\note{
Renumbered for the 4th edition: in the 3rd edition (AMCP 1.x) these data were Table 12.21 (\code{chapter_12_table_21} / \code{C12T21}). The data are unchanged.
}
\section{Variables}{

\describe{
\item{DV}{dependent variable; the number of aggressive behaviors in a time period}
\item{Subject}{one pair of monkeys (6 total)}
\item{Time}{time period}
\item{Condition}{treatment condition}
\item{Square}{a numeric vector}
}
}

\section{Synonym}{

C12T29
}

\examples{
# Load the data
data(chapter_12_table_29)

# Or, alternatively load the data as
data(C12T29)

# View the structure
str(chapter_12_table_29)

}
\references{
Maxwell, S. E., Delaney, H. D., & Kelley, K. (2027). \emph{Designing experiments and analyzing data:
{A} model comparison perspective} (4th ed.). New York, NY: Routledge.
}
\author{
Ken Kelley \email{kkelley@nd.edu}
}
\keyword{datasets}
