% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/documentation.R
\docType{data}
\name{chapter_13_table_5}
\alias{chapter_13_table_5}
\alias{Chapter_13_Table_5}
\alias{C13T5}
\alias{c13t5}
\title{The data used in Chapter 13, Table 5}
\format{
An object of class \code{data.frame} with 14 rows and 4 columns.
}
\source{
\url{https://designingexperiments.com/data/}

Maxwell, S. E., Delaney, H. D., & Kelley, K. (2027). \emph{Designing experiments and
analyzing data: {A} model comparison perspective}. (4th ed.). New York, NY: Routledge.
}
\usage{
data(chapter_13_table_5)
}
\description{
Data from Table 13.5 of \emph{Designing Experiments and Analyzing Data: A Model Comparison Perspective} (4th edition; Maxwell, Delaney, & Kelley). Two sets of hypothetical data, each consisting of two \eqn{D} (difference) variables, used to illustrate how a determinant reflects generalized variance.
}
\section{Variables}{

\describe{
\item{SetA_D1}{first D variable for data set (a)}
\item{SetA_D2}{second D variable for data set (a)}
\item{SetB_D1}{first D variable for data set (b); identical to \code{SetA_D1}}
\item{SetB_D2}{second D variable for data set (b); the same values as \code{SetA_D2} but paired with different D1 scores}
}
}

\section{Note}{

The \eqn{D_1} and \eqn{D_2} variables are \strong{derived} scores (difference
scores). The book presents only these \eqn{D} values, not the raw data from
which they were computed, so this data set contains only the D1 and D2 values
and no underlying observations. Data sets (a) and (b) share identical D1 and
D2 values, but paired differently: each variable by itself has the same sum
(0) and sum of squares (56.00 for D1, 56.38 for D2) in both sets, yet the two
sets differ in generalized variance. The determinant of the \eqn{2 \times 2}
matrix of D1 and D2 sums of squares and cross-products is 21.28 for data set
(a) and 3157.03 for data set (b).

In the 4th edition the 3rd-edition Table 13.5 (the McCarthy repeated-measures
data) was renumbered to Table 13.6, which is shipped as
\code{chapter_13_table_6}.
}

\section{Synonym}{

C13T5
}

\examples{
# Load the data
data(chapter_13_table_5)

# Or, alternatively load the data as
data(C13T5)

# View the structure
str(chapter_13_table_5)

# Brief summary of the data.
summary(chapter_13_table_5)

}
\references{
Maxwell, S. E., Delaney, H. D., & Kelley, K. (2027). \emph{Designing experiments and analyzing data:
{A} model comparison perspective} (4th ed.). New York, NY: Routledge.
}
\author{
Ken Kelley \email{kkelley@nd.edu}
}
\keyword{datasets}
