% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/documentation.R
\docType{data}
\name{chapter_12_exercise_23}
\alias{chapter_12_exercise_23}
\alias{Chapter_12_Exercise_23}
\alias{C12E23}
\alias{c12e23}
\title{The data used in Chapter 12, Exercise 23}
\format{
An object of class \code{data.frame} with 38 rows and 10 columns.
}
\source{
\url{https://designingexperiments.com/data/}

Maxwell, S. E., Delaney, H. D., & Kelley, K. (2027). \emph{Designing experiments and
analyzing data: {A} model comparison perspective}. (4th ed.). New York, NY: Routledge.
}
\usage{
data(chapter_12_exercise_23)
}
\description{
Data from Chapter 12 Exercise 23 of \emph{Designing Experiments and Analyzing Data: A Model Comparison Perspective} (4th edition; Maxwell, Delaney, & Kelley). The one-week follow-up to the Hu et al. (2015) sleep study of Exercise 22, adding a delayed measurement so that each participant now has six bias scores (cued and uncued, at prenap, postnap, and one-week delayed). Two of the 40 participants lacked delayed scores, so this data set has 38 rows. The exercise analyzes the scores as a 2 (cuing) by 3 (time) fully within-subjects design; lower scores indicate less bias.
}
\section{Variables}{

\describe{
\item{Sample}{data collection: 1 = original sample, 2 = replication sample}
\item{CuedBiasType}{the bias that was cued during the nap: \code{Gender} or \code{Race}}
\item{Cued_Baseline}{cued-bias score at baseline}
\item{Uncued_Baseline}{uncued-bias score at baseline}
\item{Cued_Prenap}{cued-bias score before the nap}
\item{Cued_Postnap}{cued-bias score after the nap}
\item{Cued_Delayed}{cued-bias score at the one-week follow-up}
\item{Uncued_Prenap}{uncued-bias score before the nap}
\item{Uncued_Postnap}{uncued-bias score after the nap}
\item{Uncued_Delayed}{uncued-bias score at the one-week follow-up}
}
}

\section{Synonym}{

C12E23
}

\examples{
# Load the data
data(chapter_12_exercise_23)

# Or, alternatively load the data as
data(C12E23)

# View the structure
str(chapter_12_exercise_23)

# Brief summary of the data.
summary(chapter_12_exercise_23)

}
\references{
Hu, X., Antony, J. W., Creery, J. D., Vargas, I. M., Bodenhausen, G. V., & Paller, K. A. (2015). Unlearning implicit social biases during sleep. \emph{Science, 348}, 1013--1015.

Maxwell, S. E., Delaney, H. D., & Kelley, K. (2027). \emph{Designing experiments and analyzing data:
{A} model comparison perspective} (4th ed.). New York, NY: Routledge.
}
\author{
Ken Kelley \email{kkelley@nd.edu}
}
\keyword{datasets}
