% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/documentation.R
\docType{data}
\name{chapter_7_exercise_23}
\alias{chapter_7_exercise_23}
\alias{Chapter_7_Exercise_23}
\alias{C7E23}
\alias{c7e23}
\title{The data used in Chapter 7, Exercise 23}
\format{
An object of class \code{data.frame} with 68 rows and 4 columns.
}
\source{
\url{https://designingexperiments.com/data/}

Maxwell, S. E., Delaney, H. D., & Kelley, K. (2027). \emph{Designing experiments and
analyzing data: {A} model comparison perspective}. (4th ed.). New York, NY: Routledge.
}
\usage{
data(chapter_7_exercise_23)
}
\description{
Data from Chapter 7 Exercise 23 of \emph{Designing Experiments and Analyzing Data: A Model Comparison Perspective} (4th edition; Maxwell, Delaney, & Kelley).
}
\details{
\itemize{
\item id.
\item esteem.
\item cond.
\item mood.}
}
\section{Synonym}{

C7E23
}

\examples{
# Load the data
data(chapter_7_exercise_23)

# Or, alternatively load the data as
data(C7E23)

# View the structure
str(chapter_7_exercise_23)

# Brief summary of the data.
summary(chapter_7_exercise_23)

}
\references{
Maxwell, S. E., Delaney, H. D., & Kelley, K. (2027). \emph{Designing experiments and analyzing data:
{A} model comparison perspective} (4th ed.). New York, NY: Routledge.
}
\author{
Ken Kelley \email{kkelley@nd.edu}
}
\keyword{datasets}
