% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/documentation.R
\docType{data}
\name{tutorial_1_table_1}
\alias{tutorial_1_table_1}
\alias{T1T1}
\alias{t1t1}
\title{The data used in Tutorial 1, Table 1}
\format{
An object of class \code{data.frame} with 103 rows and 1 columns.
}
\source{
\url{https://designingexperiments.com/data/}

Maxwell, S. E., Delaney, H. D., & Kelley, K. (2027). \emph{Designing experiments and
analyzing data: {A} model comparison perspective}. (4th ed.). New York, NY: Routledge.
}
\usage{
data(tutorial_1_table_1)
}
\description{
Data from Tutorial 1 Table 1 of \emph{Designing Experiments and Analyzing Data: A Model Comparison Perspective} (4th edition; Maxwell, Delaney, & Kelley). Beck Depression Inventory (BDI) scores for 103 adults (Smith, Meyers, & Delaney, 1998), used in Tutorial 1 to review basic descriptive statistics (the scores range from 0 to 43, with mean 15.748, median 13, and mode 9).
}
\details{
\itemize{
\item BDI.}
}
\section{Synonym}{

T1T1
}

\examples{
# Load the data
data(tutorial_1_table_1)

# Or, alternatively load the data as
data(T1T1)

# View the structure
str(tutorial_1_table_1)

# Brief summary of the data.
summary(tutorial_1_table_1)

}
\references{
Maxwell, S. E., Delaney, H. D., & Kelley, K. (2027). \emph{Designing experiments and analyzing data:
{A} model comparison perspective} (4th ed.). New York, NY: Routledge.
}
\author{
Ken Kelley \email{kkelley@nd.edu}
}
\keyword{datasets}
