% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/documentation.R
\docType{data}
\name{chapter_12_exercise_24}
\alias{chapter_12_exercise_24}
\alias{Chapter_12_Exercise_24}
\alias{C12E24}
\alias{c12e24}
\title{The data used in Chapter 12, Exercise 24}
\format{
An object of class \code{data.frame} with 118 rows and 25 columns.
}
\source{
\url{https://designingexperiments.com/data/}

Maxwell, S. E., Delaney, H. D., & Kelley, K. (2027). \emph{Designing experiments and
analyzing data: {A} model comparison perspective}. (4th ed.). New York, NY: Routledge.
}
\usage{
data(chapter_12_exercise_24)
}
\description{
Data from Chapter 12 Exercise 24 of \emph{Designing Experiments and Analyzing Data: A Model Comparison Perspective} (4th edition; Maxwell, Delaney, & Kelley). The Carnes, Lickel, and Janoff-Bulman (2015) study of how social contexts shape beliefs about moral principles. Each of 118 participants rated the importance of six moral principles in each of four social contexts, giving 24 ratings per participant, each on a scale from 1 (not at all important) to 9 (extremely important). Variables are named \code{PRINCIPLE_CONTEXT}, where the principle is CARE, FAIR, LOYA, AUTH, PURE, or JUST and the context is SOC (social category), TAS (task group), INT (intimacy group), or LOO (loose association).
}
\section{Variables}{

\describe{
\item{ID}{participant identifier}
\item{CARE_SOC}{Care, rated in the social category context}
\item{CARE_TAS}{Care, rated in the task group context}
\item{CARE_INT}{Care, rated in the intimacy group context}
\item{CARE_LOO}{Care, rated in the loose association context}
\item{FAIR_SOC}{Fairness, rated in the social category context}
\item{FAIR_TAS}{Fairness, rated in the task group context}
\item{FAIR_INT}{Fairness, rated in the intimacy group context}
\item{FAIR_LOO}{Fairness, rated in the loose association context}
\item{LOYA_SOC}{Loyalty, rated in the social category context}
\item{LOYA_TAS}{Loyalty, rated in the task group context}
\item{LOYA_INT}{Loyalty, rated in the intimacy group context}
\item{LOYA_LOO}{Loyalty, rated in the loose association context}
\item{AUTH_SOC}{Authority, rated in the social category context}
\item{AUTH_TAS}{Authority, rated in the task group context}
\item{AUTH_INT}{Authority, rated in the intimacy group context}
\item{AUTH_LOO}{Authority, rated in the loose association context}
\item{PURE_SOC}{Purity, rated in the social category context}
\item{PURE_TAS}{Purity, rated in the task group context}
\item{PURE_INT}{Purity, rated in the intimacy group context}
\item{PURE_LOO}{Purity, rated in the loose association context}
\item{JUST_SOC}{Justice, rated in the social category context}
\item{JUST_TAS}{Justice, rated in the task group context}
\item{JUST_INT}{Justice, rated in the intimacy group context}
\item{JUST_LOO}{Justice, rated in the loose association context}
}
}

\section{Synonym}{

C12E24
}

\examples{
# Load the data
data(chapter_12_exercise_24)

# Or, alternatively load the data as
data(C12E24)

# View the structure
str(chapter_12_exercise_24)

# Brief summary of the data.
summary(chapter_12_exercise_24)

}
\references{
Carnes, N. C., Lickel, B., & Janoff-Bulman, R. (2015). Shared perceptions: Morality is embedded in social contexts. \emph{Personality and Social Psychology Bulletin, 41}, 351--362.

Maxwell, S. E., Delaney, H. D., & Kelley, K. (2027). \emph{Designing experiments and analyzing data:
{A} model comparison perspective} (4th ed.). New York, NY: Routledge.
}
\author{
Ken Kelley \email{kkelley@nd.edu}
}
\keyword{datasets}
